<?php

namespace Andy\FirstPostEmail\XF\Pub\Controller;

use XF\Mvc\ParameterBag;

class Forum extends XFCP_Forum
{
	protected function finalizeThreadCreate(\XF\Service\Thread\Creator $creator)
	{
		//########################################
		// New thread was used to create first
		// post. Send email to staff.
		//########################################
		
		// get parent
		$parent = parent::finalizeThreadCreate($creator);
		
		// get visitor
		$visitor = \XF::visitor();
		
		// get messageCount
		$messageCount = $visitor['message_count'];
		
		// if first post
		if ($messageCount == 0)
		{
			// get thread
			$thread = $creator->getThread();

			// get options
			$options = \XF::options();

			// get options from Admin CP -> Options -> First post email -> Email to usernames   
			$emailToUsernames = $options->firstPostEmailEmailToUsernames;		

			// continue if we have emailToUsernames
			if (!empty($emailToUsernames))
			{
				// get subject
				$subject = \XF::phrase('firstpostemail_subject') . ' ' . $visitor['username'];
				
				// get db
				$db = \XF::db();
				
				// run query
				$threads = $db->fetchAll("
				SELECT xf_thread.thread_id,
				xf_thread.title,
				xf_thread.username,
				xf_node.title AS forumTitle
				FROM xf_post
				INNER JOIN xf_thread ON xf_thread.thread_id = xf_post.thread_id
				INNER JOIN xf_node ON xf_node.node_id = xf_thread.node_id
				WHERE xf_post.post_id = ?
				", $thread['first_post_id']);

				// send emails
				foreach ($emailToUsernames as $value) 
				{
					$user = \XF::app()->find('XF:User', $value);
					$mail = \XF::app()->mailer()->newMail();
					$mail->setToUser($user);	

					$mail->setTemplate('andy_firstpostemail', [
						'subject' => $subject,
						'threads' => $threads
					]);

					$mail->queue();
				}
			}
		}
		
		// return parent
		return $parent;
	}
}