<?php

namespace Andy\FirstPostEmail\XF\Pub\Controller;

class Thread extends XFCP_Thread
{
	protected function getNewPostsReply(\XF\Entity\Thread $thread, $lastDate)
	{
		//########################################
		// Quick editor was used to create first
		// post. Send email to staff.
		//########################################
				
		// get parent
		$parent = parent::getNewPostsReply($thread, $lastDate);
		
		// get visitor
		$visitor = \XF::visitor();
		
		// get messageCount
		$messageCount = $visitor['message_count'];
		
		// if first post
		if ($messageCount == 0)
		{
			// get posts
			$posts = $parent->getParam('posts');

			// get last
			$last = $posts->last();

			// get postId
			$postId = $last->post_id;

			// get userId
			$userId = $visitor['user_id'];			

			// get options
			$options = \XF::options();
			
			// get options from Admin CP -> Options -> First post email -> Email usernames   
			$emailUsernames = $options->firstPostEmailEmailUsernames;
			
			// continue if we have emailToUsernames
			if (!empty($emailToUsernames))
			{
				// get subject
				$subject = \XF::phrase('firstpostemail_subject') . ' ' . $visitor['username'];

				// get db
				$db = \XF::db();

				// run query
				$posts = $db->fetchAll("
				SELECT xf_post.post_id,
				xf_thread.title,
				xf_thread.username,
				xf_node.title AS forumTitle
				FROM xf_post
				INNER JOIN xf_thread ON xf_thread.thread_id = xf_post.thread_id
				INNER JOIN xf_node ON xf_node.node_id = xf_thread.node_id
				WHERE xf_post.post_id = ?
				", $postId);

				// send emails
				foreach ($emailUsernames as $value) 
				{
					$user = \XF::app()->find('XF:User', $value);
					$mail = \XF::app()->mailer()->newMail();
					$mail->setToUser($user);	

					$mail->setTemplate('andy_firstpostemail', [
						'subject' => $subject,
						'posts' => $posts
					]);

					$mail->queue();
				}
			}
		}
		
		// return parent
		return $parent;
	}
}